# CHANGELOG

### @TODO:
- improve the code


## Version 0.1.8
- BRAKE: the mode how the ProgressBar is reimplemented will brake the old code. Use the example from README.md
- reword on the progress bar and threads. For now seams to work OK
- small fixes for documentation and added some images

## Version 0.1.7
- refactored all the code
- split the code in separate files
- added ProgressBar with threads and callback

## Version 0.1.6
- change the mode how the versions are experimented
## Version 1.0.4
- modification on how the GTK is imported and version specified
## Version 1.0.3
- small modification on readme and another push to PyPi
## Version 1.0.1
- initial release
